@@ -6,10 +6,10 @@ import time
 
 _logger = logging.getLogger(__name__)
 
-FILENAME_PEM_PRIVATE_KEY = 'ca_private.pem'
-FILENAME_PEM_PUBLIC_KEY = 'ca_public.pem'
-FILENAME_PEM_CSR = 'ca_csr.pem'
-FILENAME_PEM_CERTIFICATE = 'ca_cert.pem'
+FILENAME_PEM_PRIVATE_KEY = 'ca.private_key.pem'
+FILENAME_PEM_PUBLIC_KEY = 'ca.public_key.pem'
+FILENAME_PEM_CSR = 'ca.csr.pem'
+FILENAME_PEM_CERTIFICATE = 'ca.cert.pem'
 
 REQUIRED_DN_FIELDS = set(('C', 'ST', 'L', 'O', 'CN', 'emailAddress'))
 BITS = 2048
